==> pcsx2_1.3.1+dfsg.orig.tar.xz: pcsx2-1.3.1/common/src/Utilities/AlignedMalloc.cpp <==
/*  PCSX2 - PS2 Emulator for PCs
 *  Copyright (C) 2002-2010  PCSX2 Dev Team
 *
 *  PCSX2 is free software: you can redistribute it and/or modify it under the terms
 *  of the GNU Lesser General Public License as published by the Free Software Found-
 *  ation, either version 3 of the License, or (at your option) any later version.
 *
 *  PCSX2 is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 *  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *  PURPOSE.  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with PCSX2.
 *  If not, see <http://www.gnu.org/licenses/>.
 */

// This module contains implementations of _aligned_malloc for platforms that don't have
// it built into their CRT/libc.

#include "PrecompiledHeader.h"

struct AlignedMallocHeader
{
	u32 size;		// size of the allocated buffer (minus alignment and header)
	void* baseptr;	// offset of the original allocated pointer
};

static const uint headsize = sizeof(AlignedMallocHeader);

void* __fastcall pcsx2_aligned_malloc(size_t size, size_t align)
{
	pxAssert( align < 0x10000 );

#if defined(__USE_ISOC11) && !defined(ASAN_WORKAROUND) // not supported yet on gcc 4.9
	return aligned_alloc(align, size);
#else
	u8* p = (u8*)malloc(size+align+headsize);

	// start alignment calculations from past the header.
	uptr pasthead = (uptr)(p+headsize);
	uptr aligned = (pasthead + align-1) & ~(align-1);

	AlignedMallocHeader* header = (AlignedMallocHeader*)(aligned-headsize);
	pxAssert( (uptr)header >= (uptr)p );

	header->baseptr = p;
	header->size = size;

	return (void*)aligned;
#endif
}

void* __fastcall pcsx2_aligned_realloc(void* handle, size_t size, size_t align)
{
	pxAssert( align < 0x10000 );

	void* newbuf = pcsx2_aligned_malloc( size, align );

	if( handle != NULL )
	{
#if defined(__USE_ISOC11) && !defined(ASAN_WORKAROUND) // not supported yet on gcc 4.9
		memcpy_fast( newbuf, handle, size );
		free( handle );
#else
		AlignedMallocHeader* header = (AlignedMallocHeader*)((uptr)handle - headsize);
		memcpy_fast( newbuf, handle, std::min( size, header->size ) );
		free( header->baseptr );
#endif
	}
	return newbuf;
}

__fi void pcsx2_aligned_free(void* pmem)
{
#if defined(__USE_ISOC11) && !defined(ASAN_WORKAROUND) // not supported yet on gcc 4.9
	free(pmem);
#else
	if( pmem == NULL ) return;
	AlignedMallocHeader* header = (AlignedMallocHeader*)((uptr)pmem - headsize);
	free( header->baseptr );
#endif
}

// ----------------------------------------------------------------------------
// And for lack of a better home ...


// Special unaligned memset used when all other optimized memsets fail (it's called from
// memzero_obj and stuff).
__fi void _memset16_unaligned( void* dest, u16 data, size_t size )
{
	pxAssume( (size & 0x1) == 0 );

	u16* dst = (u16*)dest;
	for(int i=size; i; --i, ++dst )
		*dst = data;
}

__fi void HostSys::Munmap( void* base, size_t size )
{
	Munmap( (uptr)base, size );
}

==> pcsx2_1.4.0+dfsg.orig.tar.xz: pcsx2-1.4.0/common/src/Utilities/AlignedMalloc.cpp <==
/*  PCSX2 - PS2 Emulator for PCs
 *  Copyright (C) 2002-2010  PCSX2 Dev Team
 *
 *  PCSX2 is free software: you can redistribute it and/or modify it under the terms
 *  of the GNU Lesser General Public License as published by the Free Software Found-
 *  ation, either version 3 of the License, or (at your option) any later version.
 *
 *  PCSX2 is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 *  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *  PURPOSE.  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with PCSX2.
 *  If not, see <http://www.gnu.org/licenses/>.
 */

// This module contains implementations of _aligned_malloc for platforms that don't have
// it built into their CRT/libc.

#include "PrecompiledHeader.h"

void* __fastcall _aligned_malloc(size_t size, size_t align)
{
	pxAssert( align < 0x10000 );
#if defined(__USE_ISOC11) && !defined(ASAN_WORKAROUND) // not supported yet on gcc 4.9
	return aligned_alloc(align, size);
#else
	void *result = 0;
	posix_memalign(&result, align, size);
	return result;
#endif
}

void* __fastcall pcsx2_aligned_realloc(void* handle, size_t new_size, size_t align, size_t old_size)
{
	pxAssert( align < 0x10000 );

	void* newbuf = _aligned_malloc(new_size, align);

	if (newbuf != NULL && handle != NULL) {
		memcpy(newbuf, handle, std::min(old_size, new_size));
		_aligned_free(handle);
	}
	return newbuf;
}

__fi void _aligned_free(void* pmem)
{
	free(pmem);
}
